Crate stepflow_flow

Crate stepflow_flow 

Stepflow workflow definition types.

This crate provides the core data types for defining Stepflow workflows:

Re-exports

pub use error_stack::ErrorStack;
pub use error_stack::ErrorStackEntry;
pub use values::ValueExpr;

Modules

discriminator_schema
Reusable schemars transforms for adding OpenAPI discriminators to tagged enum schemas.
error_stack
json_schema
Utility for generating standalone JSON Schema documents from schemars::JsonSchema types.
schema
Schema manipulation and validation types.
values
Value handling and resolution for Stepflow flows.
workflow

Structs

FlowError
An error reported from within a flow or step.

Enums

FlowResult
The results of a step execution.
TaskErrorCode
Categorizes the type of error that occurred during task execution.