FlowBuilder

Struct FlowBuilder 

pub struct FlowBuilder { /* private fields */ }
Builder for creating Flow instances with reduced boilerplate.

Implementations

Source

impl FlowBuilder

pub fn new() -> Self

Create a new FlowBuilder with default values.

pub fn name<S: Into<String>>(self, name: S) -> Self

Set the flow name.

pub fn description<S: Into<String>>(self, desc: S) -> Self

Set the flow description.

pub fn version<S: Into<String>>(self, version: S) -> Self

Set the flow version.

pub fn input_schema(self, schema: SchemaRef) -> Self

Set the input schema.

pub fn output_schema(self, schema: SchemaRef) -> Self

Set the output schema.

pub fn step(self, step: Step) -> Self

Add a single step to the flow.

pub fn steps<I: IntoIterator<Item = Step>>(self, steps: I) -> Self

Add multiple steps to the flow.

pub fn output(self, output: ValueExpr) -> Self

Set the flow output.

pub fn variables(self, variables: VariableSchema) -> Self

Set the variables schema for the flow.

pub fn test_config(self, test: TestConfig) -> Self

Set the test configuration.

pub fn examples(self, examples: Vec<ExampleInput>) -> Self

Set the examples.

pub fn metadata<S: Into<String>>(self, key: S, value: Value) -> Self

Add metadata.

pub fn test_flow() -> Self

Create a builder for a test flow with a default name.

pub fn mock_flow() -> Self

Create a builder for a mock flow with common test defaults.

pub fn build(self) -> Flow

Build the final Flow instance.