Re-exports
pub use error_stack::ErrorStack;pub use error_stack::ErrorStackEntry;pub use values::ValueExpr;
Modules
- discriminator_
schema - Reusable schemars transforms for adding OpenAPI discriminators to tagged enum schemas.
- error_
stack - json_
schema - Utility for generating standalone JSON Schema documents from schemars::JsonSchema types.
- schema
- Schema manipulation and validation types.
- values
- Value handling and resolution for Stepflow flows.
- workflow
Structs
- Flow
Error - An error reported from within a flow or step.
Enums
- Flow
Result - The results of a step execution.
- Task
Error Code - Categorizes the type of error that occurred during task execution.