Module workflow

Module workflow 

Re-exports

pub use crate::values::JsonPath;
pub use crate::values::PathPart;
pub use crate::values::ValueRef;

Structs

Component
Identifies a specific plugin and atomic functionality to execute.
DefaultOverrideProcessor
Default implementation of override processing
ExampleInput
An example input for a workflow that can be used in UI dropdowns.
Flow
A workflow consisting of a sequence of steps and their outputs.
FlowBuilder
Builder for creating Flow instances with reduced boilerplate.
FlowRef
A wrapper around Arc<Flow> to support poem-openapi traits.
FlowSchema
Consolidated schema information for a flow.
Step
A step in a workflow that executes a component with specific arguments.
StepBuilder
Builder for creating Step instances with reduced boilerplate.
StepOverride
Override specification for a single step.
TestCase
A single test case for a workflow.
TestConfig
Configuration for testing a workflow.
VariableSchema
Variable schema for workflow variables using JSON Schema format.
WorkflowOverrides
Workflow overrides that can be applied to modify step behavior at runtime.

Enums

ErrorAction
Error action determines what happens when a step fails.
OverrideError
Errors that can occur when applying workflow overrides
OverrideType
The type of override operation to perform.
StepId
A step identifier that provides access to both the step index and name.
VariableValidationError
Errors that can occur during variable validation.

Traits

OverrideProcessor
Trait for applying workflow overrides to flows

Functions

apply_overrides
Convenience function to apply overrides to a workflow using the default processor
builtin_step
Create a StepBuilder for a builtin step.
mock_flow
Create a FlowBuilder for a mock flow with common test defaults.
mock_step
Create a StepBuilder for a mock step.
test_flow
Create a FlowBuilder for a test flow with a default name.

Type Aliases

OverrideResult