pub struct StepBuilder { /* private fields */ }Expand description
Builder for creating Step instances with reduced boilerplate.
Implementations
Sourceimpl StepBuilder
impl StepBuilder
Sourcepub fn input_json(self, input: Value) -> Self
pub fn input_json(self, input: Value) -> Self
Set the input from a JSON value, parsing it as a ValueExpr.
Sourcepub fn input_literal(self, input: Value) -> Self
pub fn input_literal(self, input: Value) -> Self
Set the input as a literal JSON value.
Sourcepub fn on_error(self, action: ErrorAction) -> Self
pub fn on_error(self, action: ErrorAction) -> Self
Set the error action.
Sourcepub fn must_execute(self, must_execute: bool) -> Self
pub fn must_execute(self, must_execute: bool) -> Self
Set whether this step must execute even if its output is not used.
Sourcepub fn mock_step<S: Into<String>>(id: S) -> Self
pub fn mock_step<S: Into<String>>(id: S) -> Self
Create a mock step with a default mock component.
Sourcepub fn builtin_step<S: Into<String>>(id: S, component: S) -> Self
pub fn builtin_step<S: Into<String>>(id: S, component: S) -> Self
Create a builtin step with the specified builtin component.
Sourcepub fn step_ref<S: Into<String>>(id: S, ref_step: S) -> Self
pub fn step_ref<S: Into<String>>(id: S, ref_step: S) -> Self
Create a step that references another step’s output.
Sourcepub fn workflow_input<S: Into<String>>(id: S) -> Self
pub fn workflow_input<S: Into<String>>(id: S) -> Self
Create a step that references workflow input.